Attribute VB_Name = "GTED_VBA_AUTOMATION_V6_2_41"

'---------------------------------------------------
'---------------------------------------------------
'||                                               ||
'||     This code is copyright protected          ||
'||     by Gray Technical, LLC. Any copying,      ||
'||     distributing, duplicating                 ||
'||     manipulating or likewise is strictly      ||
'||     prohibited and will be enforced to        ||
'||     fullest extent of the law.                ||
'||                                               ||
'||     If you require support, please email      ||
'||     us at support@graytechnical.com           ||
'||                                               ||
'||     Version number v6.2.36                     ||
'||                                               ||
'||     last modified on 02/23/2024 12:43 aM      ||
'---------------------------------------------------
'---------------------------------------------------

' how to operate:
'
'
'Useable Commands:
'
'-----------------------------------------
'   Create Object(VBA): "GTED_Create_Object"
'-----------------------------------------
' Create an object/drawing (VBA- replace [] with variables):
'   GTED_Create_Object [OBJECT], [RANGE], [Z-ENABLED-Y/N], [RELATIVE-Y/N], [LAYER#]
'
' Variables for each are listed below
' Object = "" 'String: Type in object type. Options include:
'   "R" [rectangle],
'   "r" [rounded rectangle],
'   "L" [line],
'   "P" [2 points],
'   "p" [1 point],
'   "C" [circle],
'   "A" [arc],
'   "T" [text]
'   "l" (lower case L) [Line and Point]
'
' Range = "" 'String: Type in the range of the X1 Y1 Z1 X2 Y2 Z2 data.
''Example: "A1:F1"
'
' z Enabled = 2
'   This tells Excel Draw if Z values are enabled.
'   Options are)
'       0 = False
'       1 = True
'       2 = Excel Draw selected tab option
'
' Relative = 2
'   This tells Excel Draw if values are relative.
'   Options are)
'       0 = Absolute
'       1 = Relative
'       2 = Excel Draw selected tab option
'
' Layer = 0
' This option selects which layer the object needs to be created on
'
'
'
'
'-----------------------------------------
'   Producing Graph(VBA): "GTED_Generate_Graph"
'-----------------------------------------
'   To generate the graph, after objects have been
' created, simply call the VBA function below:
'
'   GTED_Generate_Graph
'
'
'
'
'-----------------------------------------
'   Generate Default Graphing Values(VBA): "GTED_Generate_Defaults"
'-----------------------------------------
' This will create default values for graphs. This is used to automatically
' generate any values needed to properly graph plotted objects.
'
' Use this after generating all objects to populate graph with default
' values for zoom, rotations, panning, object structure, color, etc.
'
' To use this, call function bellow:
'
'       GTED_Generate_Defaults
'
'
'
'
'
'-----------------------------------------
'   Generate Current Rotations and Zoom Values(VBA): "GTED_Refresh_Settings"
'-----------------------------------------
' This will regenerate settings that were previously set for
' Rotation, Pan, Zoom
'
' Example on how to call:
'
'       GTED_Refresh_Settings
'
'
'
'
'-----------------------------------------
'   Update Rotations(VBA): "GTED_Set_Rotations"
'-----------------------------------------
' Update rotations by degrees (VBA- replace [] with variables):
'  GTED_Set_Rotations [X Value as degrees], [Y Value as degrees], [Z value as degrees]
'
'   Each variable is defined as an integer.
'   Proper input values can range from 0 to 360
'
' Example:
'
'       GTED_Set_Rotations 0, 0, 180
'
'
'
'
'
'-----------------------------------------
'   Update Pan(VBA): "GTED_Set_Pan"
'-----------------------------------------
' Update pan by integer (VBA- replace [] with variables):
'  GTED_Set_Rotations [X], [Y]
'
'   Each variable is defined as an integer.
'   Proper input values can range from -100 to 100
'
' Example:
'
'       GTED_Set_Pan 0, 0
'
'
'
'
'
'
'-----------------------------------------
'   Update Zoom(VBA): "GTED_Set_Zoom"
'-----------------------------------------
' Update zoom by integer (VBA- replace [] with variables):
'  GTED_Set_Rotations [Zoom as integer]
'
'   Each variable is defined as an integer.
'   Proper input values can range from 0 to 100
'
'   This value is generated as a percentage based on the
'       scrollbar min/max of the zoom funtion located in
'       the 3D Graph Orientation Window. This scrollbar
'       min/max is generated differently depending on the
'       objects being graphed. This is automatically adjusted
'       when new objects are added.
'
'   Best practace is to use this VBA Call after all objects
'   have been created.
'
' Example:
'
'       GTED_Set_Zoom(20)
'           OR
'       FTED_Set_Zoom 20
'
'
'
'
'--------------------------------------
'   Sets the size and location for Graph(VBA): "GTED_Set_GraphLocation"
'--------------------------------------
' Update or set the Location (Top, Left) and Size (Height, Width)
' of the chart using the following function (VBA- replace [] variables):
'       GTED_Set_ChartLocation [Top], [Left], [Height], [Width]
'
'   When called, the values of location and size of graphed
'   chart is updated, but not populated. To populate you will
'   need to also re-generate the graph.
'
' Example of code:
'       GTED_Set_GraphLocation 100, 100, 500, 500





'---------------------------------------------------
'---------------------------------------------------

'---------------------------------------------------
'---------------------------------------------------

'---------------------------------------------------
'---------------------------------------------------


'---------------------------------------------------
'   Objects and the values for each
'---------------------------------------------------

'   From here down are examples of the objects and
'   how to format the values in XYZ Locations

' Variables for each are listed below
' Object = "" 'String: Type in object type. Options include:
'
'   "R" [rectangle], and "r" [rounded rectangle],
'   X1, Y1, Z1 = Starting point of rectangle (bottom left)
'   X2, Y2, Z2 = Ending point of rectangle (top right)
'
'   "L" [line],
'   X1, Y1, Z1 = Starting Point of line
'   X2, Y2, Z2 = End Point of line
'
'   "P" [Point],
'   X1, Y1, Z1 = Point location
'
'   "C" [circle],
'   X1, Y1, Z1 = Center of Circle
'   X2 = Radius
'
'   "A" [arc],
'   X1, Y1, Z1 = Center of Circle/Arc
'   X2 = Radius
'   Y2 = Starting angle in degrees
'   Z2 = Ending angle in degrees
'
'   "T" [text]
'   X1, Y1, Z1 = Starting point of text (bottom left of first letter)
'   X2 = Text
'   Y2 = Custom Text Size (optional)
'   Z2 = Custom Text Color in ACI (optional)
'
'   "l" (lower case L) [Line and Point]

'---------------------------------------------------
'---------------------------------------------------

'---------------------------------------------------
'---------------------------------------------------

'---------------------------------------------------
'---------------------------------------------------





'From this point down is the code to operate the application


'---------------------------------------------------
'---------------------------------------------------

'---------------------------------------------------
'---------------------------------------------------

'---------------------------------------------------
'---------------------------------------------------





Dim oApp As Object
Dim Object_Type As String
Dim Object_Range As String
Dim Current_Version_Excel_Draw As String
Dim Object_Z As Integer
Dim Object_Relative_ As Integer
Dim Object_Layer As Integer
Dim wb As AddIn




'-----------------------------
' general functions
'-----------------------------


Sub GTED_Create_Object(ObjectType_R_Rectangle__r_RoundedRectangle__L_Line__P_2Poitns__p_1Point__C_Circle__A_Arc__T_Text__l_lowerCaseL_LineANDPoint As String, ObjectRange As String, IsZEnabled_0_No__1_Yes__2_Default As Integer, IsDataRelative__0_Absolute__1_Relative___2_Default As Integer, Layer__0_through_9 As Integer)

    If Layer__0_through_9 > 9 Then Layer__0_through_9 = 9
    If Layer__0_through_9 < 0 Then Layer__0_through_9 = 0
    

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    
    'Decares object, range
    Object_Type = ObjectType_R_Rectangle__r_RoundedRectangle__L_Line__P_2Poitns__p_1Point__C_Circle__A_Arc__T_Text__l_lowerCaseL_LineANDPoint
    Object_Range = ObjectRange
    Object_Z = IsZEnabled_0_No__1_Yes__2_Default
    Object_Relative_ = IsDataRelative__0_Absolute__1_Relative___2_Default
    Object_Layer = Layer__0_through_9

    'Creates the object
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!ExcelDrawCreateObjectType", Object_Type, Object_Range, Object_Z, Object_Relative_, Object_Layer)

End Sub


Sub GTED_Generate_Defaults()

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!CreateLables_ED4_GT_API")

End Sub


Sub GTED_Refresh_Settings()

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!UpdateRoationsXYZZ_API")
    
End Sub




'---------------------------------
' gather Graph Data
'---------------------------------

Function GTED_Get_Rotation_X() As Integer
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!CreateLables_ED4_GT_API")
    On Error Resume Next
    GTED_Get_Rotation_X = CInt(ActiveWorkbook.ActiveSheet.Labels("ED_GT_XROT").Caption)
    On Error GoTo 0
End Function

Function GTED_Get_Rotation_Y() As Integer
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!CreateLables_ED4_GT_API")
    On Error Resume Next
    GTED_Get_Rotation_Y = CInt(ActiveWorkbook.ActiveSheet.Labels("ED_GT_YROT").Caption)
    On Error GoTo 0
End Function

Function GTED_Get_Rotation_Z() As Integer
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!CreateLables_ED4_GT_API")
    On Error Resume Next
    GTED_Get_Rotation_Z = CInt(ActiveWorkbook.ActiveSheet.Labels("ED_GT_ZROT").Caption)
    On Error GoTo 0
End Function




Function GTED_Get_Pan_X() As Integer
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!CreateLables_ED4_GT_API")
    On Error Resume Next
    GTED_Get_Pan_X = CInt(ActiveWorkbook.ActiveSheet.Labels("ED_GT_XPAN").Caption)
    On Error GoTo 0
End Function

Function GTED_Get_Pan_Y() As Integer
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!CreateLables_ED4_GT_API")
    On Error Resume Next
    GTED_Get_Pan_Y = CInt(ActiveWorkbook.ActiveSheet.Labels("ED_GT_YPAN").Caption)
    On Error GoTo 0
End Function


Function GTED_Get_Zoom() As Integer
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!CreateLables_ED4_GT_API")
    On Error Resume Next
    Dim RawZoom As Double
    RawZoom = CInt(ActiveWorkbook.ActiveSheet.Labels("ED_GT_ZOOM").Caption)
    GTED_Get_Zoom = Math.Round(RawZoom / 30, 0)
    On Error GoTo 0
End Function





'----------------------------------
'   Color Settings
'----------------------------------

Function GTED_Get_ACI_Color(R As Integer, G As Integer, B As Integer) As Integer

    Set oApp = Application
    Dim val As Integer
    Dim OrVal As Double
    
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    'On Error Resume Next

    'now change XROT to ACI
    
    val = oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!GTED_API_GetACIColorIndex_API", R, G, B)

    On Error GoTo 0
    
    GTED_Get_ACI_Color = val
      
End Function

Function GTED_Get_RGB_Color(ACI) As Variant

    Dim val As Variant
    Dim OrVal As String
    
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    On Error Resume Next

    'now change XROT to ACI
    val = oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!GTED_Get_RGB_Color_From_ACI_Index_API", ACI)

    On Error GoTo 0
    
    GTED_Get_RGB_Color = val
      
End Function


Sub GTED_Set_Layer_Object(Layer__0_to_9_for_layers___and_10_for_Background As Integer, Obj__Line_Rectangle_Circle_Point_Arc_Distance_Text_Background As String)

    Dim Obj As String
    Obj = Obj__Line_Rectangle_Circle_Point_Arc_Distance_Text_Background

    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    On Error Resume Next
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlzm!GTED_Set_Layer_Object_API", Layer, Obj)
    On Error GoTo 0
    
End Sub


Sub GTED_Set_Object_Color(Obj__Line_Rectangle_Circle_Point_Arc_Distance_Text_Background As String, R As Integer, G As Integer, B As Integer)

    Dim Obj As String
    Obj = Obj__Line_Rectangle_Circle_Point_Arc_Distance_Text_Background
    
    
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    On Error Resume Next
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlzm!GTED_Set_Object_Color_API", Layer, Obj)
    On Error GoTo 0
    

End Sub








'----------------------------------
' Modify graph settings
'----------------------------------


Sub GTED_Graph_Ground_Layer(True_or_False As Boolean)
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Dim St As String
    If True_or_False = True Then
        St = "ExcelDrawViewGroudLayerT"
    Else
        St = "ExcelDrawViewGroudLayerF"
    End If
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!" & St)
End Sub


Sub GTED_Graph_Axis_Arms(True_or_False As Boolean)
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Dim St As String
    If True_or_False = True Then
        St = "ExcelDrawShowAxesArmsT"
    Else
        St = "ExcelDrawShowAxesArmsF"
    End If
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!" & St)
End Sub



Sub GTED_Set_Rotations(X_Degree As Integer, Y_Degree As Integer, Z_Degree As Integer)

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!UpdateRoationsXYZZ_API", X_Degree, Y_Degree, Z_Degree)
   
End Sub

Sub GTED_Set_Pan(X__Neg_100_TO_Pos_100 As Integer, Y__Neg_100_TO_Pos_100 As Integer)

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!UpdateRoationsXYZ_MOVEMENT_API", X__Neg_100_TO_Pos_100, Y__Neg_100_TO_Pos_100)
    
End Sub

Sub GTED_Set_Zoom(Zoom__0_TO_1000 As Double)

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!UpdateRotationsXYZ_ZOOM_API", Zoom__0_TO_1000)
    
End Sub


Sub GTED_Set_GraphLocation(Top As Integer, Left As Integer, Height As Integer, Width As Integer)

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!Set_The_Chart_Placement_API", Top, Left, Height, Width)
    
End Sub



Sub GTED_Generate_Graph()
    If Current_Version_Excel_Draw = "" Then Current_Version_Excel_Draw = GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!ExcelDrawPopulateDrawing")
End Sub




'-----------------------------------
' this is for exportation
'-----------------------------------

Sub ExcelDrawExportFileMacroAPI(Location As String, ExportName As String, FileType__DXF_TXT_CSV_PDF As String, OverwriteExisting As Boolean, OpenAfter As Boolean)

    Dim Tst As String
    Tst = Mid(Location, Len(Location), 1)
    If Tst <> "\" Then Location = Location & "\"

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!ExcelDrawExportFileMacroAPI", Location, ExportName, FileType__DXF_TXT_CSV_PDF, OverwriteExisting, OpenAfter)
    
End Sub




'-----------------------------------
' this part checks values for current version
'-----------------------------------


Function GTED_CheckCurrentVersion()
    Set oApp = Application
    
    For Each wb In Application.AddIns
        If Mid(wb.Name, 1, 11) = "ExcelDraw_v" Then
            Current_Version_Excel_Draw = Mid(wb.Name, 12, 25)
            Current_Version_Excel_Draw = Mid(Current_Version_Excel_Draw, 1, CInt(Len(Current_Version_Excel_Draw)) - 5)
        
        End If

    Next

    GTED_CheckCurrentVersion = Current_Version_Excel_Draw

End Function






'----------------------------------------
' This is for custom and default origin settings
'----------------------------------------

Sub GTED_Set_Origin(X_Origin As Double, Y_Origin As Double, Z_Origin As Double)

    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!SetOrigin_GT", X_Origin, Y_Origin, Z_Origin)
    
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!Set_Origin", X_Origin, Y_Origin, Z_Origin)
    
End Sub

Sub GTED_Set_Origin_Auto()
    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!Auto_Origin")
    
End Sub



'----------------------------------------
' This is for custom and ribbon settings
'----------------------------------------


Sub GTED_Layer_Coloring(True_False As Boolean)
    GTED_CheckCurrentVersion
    If Current_Version_Excel_Draw = "" Then GTED_CheckCurrentVersion
    Call oApp.Run("ExcelDraw_v" & Current_Version_Excel_Draw & ".xlam!LayerColoringOptionsAPI", True_False)
    
End Sub




